@@ -23,6 +23,7 @@ from zope.interface import implementer
 from zope.location import ILocation
 from zope.schema.fieldproperty import FieldProperty
 
+from pyams_security.security import ProtectedViewObjectMixin
 from pyams_table.column import Column, GetAttrColumn
 from pyams_table.table import Table as BaseTable
 from pyams_template.template import get_view_template
@@ -111,6 +112,9 @@ class Table(ObjectDataManagerMixin, BaseTable):
         """Table ID getter"""
         return get_table_id(self, self.context)
 
+    batch_size = 500
+    start_batching_at = 500
+
     css_classes = {
         'table': 'table table-striped table-hover table-sm datatable'
     }
@@ -202,7 +206,7 @@ class InnerTableMixin:
     def render(self):
         """Admin view renderer"""
         has_values, values = boolean_iter(self.table.values)  # pylint: disable=no-member,unused-variable
-        if not has_values:
+        if (not has_values) and not getattr(self.table, 'display_if_empty', False):
             return self.empty_template()
         return super().render()  # pylint: disable=no-member
 
@@ -283,7 +287,7 @@ class IconColumn(Column):
         """Column permission test"""
         if not self.permission:
             return True
-        return self.request.has_permission(self.permission, item)
+        return self.request.has_permission(self.permission, context=item)
 
     def get_icon(self, item):
         """Column icon getter"""
@@ -333,8 +337,13 @@ class BaseActionColumn(IconColumn):
         return absolute_url(item, self.request, self.href)
 
 
-class ActionColumn(BaseActionColumn):
-    """Base action column"""
+class ActionColumn(ProtectedViewObjectMixin, BaseActionColumn):
+    """Base action column
+
+    This column class inherits from :py:class:`ProtectedViewObjectMixin
+    <pyams_security.security.ProtectedViewObjectMixin>`, so you can use adapters
+    to define permission required to enable this action.
+    """
 
     def render_cell(self, item):
         """Column cell renderer"""
@@ -390,6 +399,8 @@ class TrashColumn(ObjectDataManagerMixin, JsActionColumn):
     hint = _("Delete element")
     icon_class = 'fa fa-trash-alt'
 
+    action_type = 'delete'
+
     href = 'MyAMS.container.deleteElement'
     modal_target = False
 
